summaryrefslogtreecommitdiffstats
path: root/kmail/snippetdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/snippetdlg.cpp')
-rw-r--r--kmail/snippetdlg.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmail/snippetdlg.cpp b/kmail/snippetdlg.cpp
index 5e26319ff..2229a7633 100644
--- a/kmail/snippetdlg.cpp
+++ b/kmail/snippetdlg.cpp
@@ -26,14 +26,14 @@
#include "kmessagebox.h"
/*
* Constructs a SnippetDlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-SnippetDlg::SnippetDlg( KActionCollection* ac, TQWidget* parent, const char* name, bool modal, WFlags fl )
- : SnippetDlgBase( parent, name, modal, fl ), actionCollection( ac )
+SnippetDlg::SnippetDlg( KActionCollection* ac, TQWidget* tqparent, const char* name, bool modal, WFlags fl )
+ : SnippetDlgBase( tqparent, name, modal, fl ), actionCollection( ac )
{
if ( !name )
setName( "SnippetDlg" );
@@ -66,7 +66,7 @@ SnippetDlg::SnippetDlg( KActionCollection* ac, TQWidget* parent, const char* nam
*/
SnippetDlg::~SnippetDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -26,14 +26,14 @@
#include "kmessagebox.h"
/*
- * Constructs a SnippetDlg as a child of 'parent', with the
+ * Constructs a SnippetDlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*